#
# spec file for package fwts
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fwts
Version:        21.05.00
Release:        1.1
Summary:        Firmware Test Suite
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://wiki.ubuntu.com/Kernel/Reference/fwts
Source0:        %{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE fwts-no-compiletime.patch
Patch1:         fwts-no-compiletime.patch
# PATCH-FIX-OPENSUSE fwts-fix-non-acpi.patch
Patch2:         fwts-fix-non-acpi.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libfdt-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(json)
BuildRequires:  pkgconfig(libbsd)
BuildRequires:  pkgconfig(libpci)
BuildRequires:  pkgconfig(libpcre)
Requires:       bash-completion
Recommends:     acpica
Recommends:     dmidecode
Recommends:     pciutils

%description
The FirmWare Test Suite (fwts) is a tool to do automatic testing of a PC's
firmware. There can be a lot of subtle or vexing Linux Kernel/firmware issues
caused when firmware is buggy, so it's useful to have a tool that can
automatically check for common BIOS and ACPI errors. Where possible the tool
will give some form of advice on how to fix issues or workaround firmware
issues.

%prep
%autosetup -p1

%build
find . -name Makefile.am -exec sed -i "s|-Werror||g"  {} +
autoreconf -fiv
%configure \
	--disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
install -D -p -m 0644 data/klog.json %{buildroot}%{_datadir}/%{name}/klog.json
install -D -p -m 0644 data/syntaxcheck.json %{buildroot}%{_datadir}/%{name}/syntaxcheck.json
# There are no headers, so drop remaining development files
rm -f "%{buildroot}/%{_libdir}/%{name}"/*.so

%files
%doc README README_ACPICA.txt README_SOURCE.txt ./data/README_JSON.txt
%doc debian/changelog
%{_bindir}/fwts
%{_bindir}/kernelscan
%{_libdir}/fwts
%{_mandir}/man1/fwts-collect.1%{?ext_man}
%{_mandir}/man1/fwts-frontend-text.1%{?ext_man}
%{_mandir}/man1/fwts.1%{?ext_man}
%{_datadir}/bash-completion/completions/fwts
%dir %{_datadir}/%{name}
%{_datadir}/fwts/clog.json
%{_datadir}/fwts/klog.json
%{_datadir}/fwts/syntaxcheck.json
%{_datadir}/fwts/olog.json

%changelog
* Mon May 24 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 21.05.00:
  * lib: fwts_version.h - update to V21.05.00
  * debian: update changelog
  * auto-packager:mkpackage.sh: add impish
  * fwts-test: sync up with dbgp changes
  * acpi: dbgp/spmi: check space ids by fwts_acpi_space_id
  * acpiinfo: update ACPI 6.4 vs. ACPICA versions
  * lib: acpi: fix incorrect actual vs. struct length outputs
  * acpi: shorten helper function names by removing "check"
  * lib: acpi: unify naming style by removing "ACPI"
  * fwts-test: sync up with PMTT refactoring changes
  * acpi: refactor length check by fwts_acpi_structure_length_check
  * acpi: refactor zero length by fwts_acpi_structure_length_zero_check
* Thu May 20 2021 Martin Pluskal mpluskal@suse.com
- Update to version 21.03.00:
  * uefirtvariable: fix memory leak
  * acpi: refactor by fwts_acpi_reserved_type_check
  * acpi: refactor by fwts_acpi_structure_range_check
  * uefirtauthvar: check variable runtime services supported before testing (LP: #1913351)
  * uefirtvariable: check variable runtime services supported before testing (LP: #1913351)
  * uefirtmisc: check misc runtime services supported before testing (LP: #1913351)
  * uefirttime: check time services supported before testing (LP: #1913351)
  * acpi: spcr: accept baud rate 0x0 as a preconfigured state
  * fwts-test: sync up with PMTT rev 2 changes
  * acpi: pmtt: update PMTT to revision 2 (mantis 1975)
* Wed Apr 28 2021 Martin Pluskal <mpluskal@suse.com>
- Switch to obs scm _service
* Thu Apr 15 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 21.03.00:
  * See provided changelog for detailed list of changes
* Thu Feb 25 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 21.02.00:
  * See provided changelog for detailed list of changes
* Fri Jan 22 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 21.01.00:
  * See provided changelog for detailed list of changes
- Drop upstreamed patch:
  * acpi-pmtt-fix-infinite-loops-when-length-is-incorrectly-zero.diff
* Mon Jan 18 2021 Martin Pluskal <mpluskal@suse.com>
- Add patch fixing bsc#1178442 bsc#1177992
  * acpi-pmtt-fix-infinite-loops-when-length-is-incorrectly-zero.diff
* Fri Dec 18 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20.12.00:
  * See provided changelog for detailed list of changes
* Tue Dec  1 2020 Martin Pluskal <mpluskal@suse.com>
- Fix broken source url and prepare done in previous changes
* Mon Nov 30 2020 ro@suse.de
- add patch fwts-fix-non-acpi.patch
  fix build on non-acpi platforms like ppc64le and s390x
* Fri Nov 27 2020 ro@suse.de
- Update to version 20.11.00:
  * See provided changelog for detailed list of changes
* Tue Sep 22 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20.09.00:
  * See provided changelog for detailed list of changes
* Wed Aug 12 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20.07.00:
  * See provided changelog for detailed list of changes
* Tue Jul 21 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20.06.01:
  * See provided changelog for detailed list of changes
* Tue May 26 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20.05.00:
  * See provided changelog for detailed list of changes
* Wed May 13 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20.03.01:
  * Small fixes
* Thu Apr  2 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20.03.00:
  * Plenty of changes
* Mon Feb  3 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20.01.00:
  * Plenty of changes
* Mon Dec  9 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 19.12.00:
  * Plenty of changes
* Thu Oct  3 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 19.09.00:
  * acpi/boot: skip ACPI BOOT test on UEFI systems.
  * acpi: s3: fix typo from 6b94bb6a4b13e
  * opal: add more bounds checking and zero pstates array
  * fwtstest: boot-0001: sync with boot table check on efi firmware
- Changes for version 19.08.00:
  * ACPICA: Update to version 20190816
  * auto-packager: mkpackage.sh: remove cosmic
  * efi_runtime: enable KBUILD_MODPOST_WARN=y to workaround build failures
  * ACPICA: Update to version 20190816
  * fwtstest: syntaxcheck-0001: update to keep in sync with ACPICA features
  * README: Add package dependency notes for ARM64
* Tue Aug 13 2019 Martin Pluskal <mpluskal@suse.com>
-  Update to version 19.07.00:
  * cpu/msr: add 3 more CPU IDs for IA32_silvermont_MSRs
  * cpu/msr: check SGX & LMCE in IA32_FEATURE_CONTROL (3ah)
  * cpu/msr: move TSC_ADJUST (3bh) to IA32_MSRs
  * cpu/msr: add SMM_MONITOR_CTL (9bh) to IA32_MSRs
  * cpu/msr: add MC*_CTL2 MSR registers
  * cpu/msr: add VMX_VMFUNC MSR register
  * cpu/msr: add MISC_ENABLE MSR to IA32_atom_MSRs
  * cpu/msr: add MSR_PMG_IO_CAPTURE_BASE to IA32_silvermont_MSRs
  * cpu/msr: add MSR_FEATURE_CONFIG to IA32_silvermont_MSRs
  * cpu/msr: add MSR_TEMPERATURE_TARGET to IA32_silvermont_MSRs
  * cpu/msr: add MSR_BBL_CR_CTL3 to IA32_silvermont_MSRs
  * ACPICA: Update to version 20190703
* Tue Jul 23 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 19.06.00:
  * acpi/fadt: update latest FADT revision to 6.3
  * uefitime: add checking the EFI_UNSUPPORTED return code
  * uefirtvariable: add checking the EFI_UNSUPPORTED return code
  * uefirtmisc: add checking the EFI_UNSUPPORTED return code
* Wed May 29 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 19.05.00:
  * ACPICA: Update to version 20190509
  * Add support for Hygon Dhyana CPU
  * dmicheck: update supported SMBIOS version
  * acpi/method: check full and battery power if acpi_video0 exists
  * dmicheck: checks type length vs. SMBIOS versions
  * dmicheck: add Type 1's Field 25 & 26 as used by kernel
  * apic: apicedge: fix typo in error messages
  * cpufreq: change from abort to skip when cpufreq cannot run
  * kernel:version: change ACPI version to ACPICA version
  * pci:crs: fix an indentation error
  * acpi: s3: check sleep type for output messages
  * snapcraft: update to core18
  * acpica: re-work fwts / iasl interface to work with latest ACPICA
  * fwts-test: refresh syntaxcheck test output
  * fwts-test/syntaxcheck: refresh syntaxcheck test output
  * fwts_acpica: don't add in RSDP or null table entries to XSDT or RSDT (LP: #1829167)
- Changes for version 19.03.00:
  * acpi: madt: Add support for ACPI 6.3
  * lib: fwts_acpi_tables: add a new function to check reserved values
  * lib: fwts_acpi_tables: rename fwts_acpi_subtable_length_check
  * srat: replace structure length checks by fwts_acpi_structure_length_check
  * acpi: refactor all table length checks to fwts_acpi_table_length_check
  * README: update installing fwts by "sudo make install"
  * acpi/fadt: reject 5.0 tables with ARM specific attributes set
  * acpi/iort: permit SMMU model values of 4 and 5
  * acpi/iort: fix error in SMMU node length check
  * ACPICA: fix IASL building issues with gcc-9 and --as-needed linker option
* Tue Mar  5 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 19.02.00:
  * klog.json: add an "IOAPIC .. not in IVRS" message
  * utilities: kernelscan: add AMD iommu for IVRS errors
  * acpi/method: check levels on full power and battery power
  * acpi: add address space types according to mantis 1965 (ACPI 6.2b)
  * acpi/pptt: check flags by revision (mantis 1870 for ACPI 6.2b)
  * acpi: pdtt: update flags defintion according to mantis 1867 (ACPI 6.3)
  * acpi/nfit: update memory mapping attributes (mantis 1873 for ACPI 6.3)
  * acpi/hmat: update for hmat revision 2 (mantis 1914 for ACPI 6.3)
  * acpi/madt: remove two reserved bytes (mantis 1934 for ACPI 6.3)
  * acpi/madt: update for Local APIC Flags (mantis 1948 for ACPI 6.3)
  * acpi/hmat: update System Locality Latency (mantis 1959 for ACPI 6.3)
  * acpi/method: add tests for NVDIMM control methods for ACPI 6.3
  * acpiinfo: update ACPI and ACPICA versions
  * acpi/srat: add test for Generic Initiator (mantis 1904 for ACPI 6.3)
  * ACPICA: Update to version 20190215
  * acpi: fix a typo in comment
  * fwts: fix up a handful of spelling mistakes
  * efi_runtime: fix access_ok build issues on 5.0 kernels
  * Makefiles: workaround address-of-packed-member warnings with gcc-9
  * acpica: utdecode: fix missing comma in array declaration AcpiGbl_GenericNotify
* Thu Feb 14 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 19.01.00:
  * mtrr: check memory type above 4GB on AMD platforms
  * ACPICA: Update to version 20190108
  * dmi: dmicheck: remove redundant new lines
  * lib: fwts_ac_adapter: fix readdir(ac_power_dir) failing
  * lib: fwts_ac_adapter: fix failing to find AC directory
  * Update copyright year to 2019
  * mtrr: fix incorrect mask on amd_sys_conf
  * sbbr: fadt: clean up major/minor version checking
  * acpi/madt: clean up indentation issue, remove tab
  * lib: fw_pm_method: move the sleep t_start time out of
    logind_on_signal (LP: #1809096)
- Changes for version 18.12.00:
  * ACPICA: Update to version 20181213
  * mtrr: allow uncached type for PCI prefetchable memory
  * lib: disable /dev/mem access on aarch64
  * dmicheck: drop unaligned memcpy
  * lib: drop fwts_memcpy_unaligned
  * dmicheck: use dmi_load_file in preference to fwts_mmap
* Thu Nov 15 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 18.11.00 (boo#1116172):
  * dmicheck: checks (Extended) Maximum Capacity for type 16
  * snapcraft: add libbsd-dev to build-packages
  * efi_runtime: re-enable the resetsystem runtime interface
  * olog:olog.json: Update OPAL skiboot errors to check on olog scan
  * acpi: button: check fixed hardware & control method power buttons
  * kernelscan: add -k option to specify klog json filename
  * src/lib: add module probing helper functions
  * lib: fwts_efi_module: use the new module loading helper functions
  * lib/fwts_cpu: use new use the new module loading helper functions
* Fri Aug 31 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 18.08.00:
  * ACPICA: Update to version 20180810
  * uefi: uefivarinfo: add to UNSAFE category
  * acpi: gtdt: add checking the valid base physical address
  * dmicheck: update Processor Upgrade field in Type 4
  * dmicheck: update connection and port types in Type 8
  * dmicheck: update Usage and Characteristics 2 fields in Type 9
  * dmicheck: update memory type and add nvdimm fields for Type 17
  * coreboot/clog/clog.c: add clog test
- Refresh patch fwts-no-compiletime.patch
- Fix typo in changelog
* Tue Jul 10 2018 mpluskal@suse.com
- Don't build with -Werror (fixes build with gcc8)
* Wed Jun 27 2018 mpluskal@suse.com
- Update to version 18.06.02:
  * ACPICA: Update to version 20180531
  * acpi: fadt: allow first reserved field to be 1
  * update_version.sh: also update version in snapcraft.yaml
  * snapcraft.yaml: add in missing stage packages
  * lib: fwts_set: fix API for fwts_set, add fwts_set_int
  * lib: add small helpers top get/set /sys/power/pm_debug_messages
  * acpi: s3: force enable /sys/power/pm_debug_messages
  * acpi: s4: also check for file based swap files
  * acpi: s4: force enable /sys/power/pm_debug_messages
  * acpi: s3power: force enable /sys/power/pm_debug_messages
  * acpi: hpet: fix getting invalid vendor ID and clock period
  * acpica: fix linking issues when building non ACPI builds
  * fwts_uefi: Fixing tiny typos in the uefi driver
  * mtrr: fix incorrect type detection
* Mon Jun 18 2018 mpluskal@suse.com
- Update to version 18.05.01:
  * No changelog available
* Fri May 18 2018 mpluskal@suse.com
- Update to version 18.05.00:
  * fan: add cooling_device# to error messages
  * doc: adding acpitests, uefitests and sbbr options to man page
  * acpi: syntaxcheck: change it from batch to batch-experimental
  * fwts_framework: add an "ifv" option for Independent Firmware Vendor
  * dmicheck: skip checks of DMI default values for IFV
  * acpi: method: add test for _CLS control method
  * lib: create helper functions for device identification objects
  * acpi: devices: add common objects
  * fwts-frontend-text: add a recommended option for IFV (IBV)
  * fwts-frontend-text: add an option for ARM SBBR
  * auto-packager: mkpackage.sh: add cosmic
  * ACPICA: Update to version 20180427
  * ACPICA: Update to version 20180508
  * README: Add libpci-dev dependency ppc64el
  * cpufreq: Add support to read boost frequencies
* Fri Apr  6 2018 mpluskal@suse.com
- Update to version 18.03.00:
  * ACPICA: Update to version 20180313
  * dmi: dmicheck: add chassis type for Type 3
  * klog.json: change severity for AE_ALREADY_EXISTS errors
  * olog:olog.json: Update OPAL skiboot errors to check on olog
    scan
  * uefirtauthvar: remove test with
    EFI_VARIABLE_AUTHENTICATED_WRITE_ACCESS
* Thu Mar  8 2018 mpluskal@suse.com
- Update to version 18.02.00:
  * ACPICA: Update to version 20180209
  * uefirtvariable: add test for
    EFI_VARIABLE_AUTHENTICATED_WRITE_ACCESS attribute
  * acpi: acpiinfo: add acpi 6 to acpiinfo test
  * acpi: method: check one element in _TSD only for acpi 6.2+
  * acpi: spcr: update interface types based on DBG2
  * acpi: method: allow _WAK to return an integer
  * mkpackage.README: change urgency level to medium
  * lib: fwts_log: remove redundant initialization of ptr1
  * acpi: wmi: remove redundant initialization of 'info'
  * lib: fwts_log: remove redundant initialization of 'field'
  * lib: fwts_pipeio: remove variable status
  * lib: fwts_acpi_tables: remove redundant initialization to
    'result'
  * README: Add dependencies per Platform
  * auto-packager: mkpackage.sh: remove zesty
  * uefirtvariable: modify both authenticated attributes setting
    test
  * acpi: fadt: Fix FACS checking
  * acpi: iort: Update revision checking
* Thu Jan 25 2018 mpluskal@suse.com
- Update to version 18.01.00:
  * ACPICA: Update to version 20180105
  * acpi: LPIT: check for monotonically increasing UID
  * fwts-test: sync up with changes in lpit test
  * Treewide: update copyright year to 2018
  * fwts-test: arg-help: sync up with copyright year changes
  * acpica: fix linking issues when building non ACPI builds
  * lib: fwts-battery: use PRIu32 format specifier, fixes cppcheck
    warning
  * acpi: acpidump: move declaration to before statements, add blank
    lines
  * lib: fwts_safe_mem: don't perform void * pointer arithmetic,
    fix 32 bit end
  * lib: fwts_alloc: move 'pos' to a deeper scope, minor style
    change
  * opal: reserve_mem: remove redundant initialization of pointer p
  * opal: reserve_mem: remove unused variable 'i' and move scope of
    variable 'value'
  * sbbr: rsdp: remove redundant initialization of boolean
    'signature_pass'
  * acpi: madt: move scope of boolean 'passed'
  * acpi: pptt: move scope of index variable 'i'.
  * acpi: rasf: move scope of index variable 'i'
  * sbbr: acpitables: clean up code, move scope of some variables
  * acpi: erst: cast size to uint64_t to clean up static analysis
    warning
  * uefi: uefidump: clean up some static analysis warnings
  * securebootcert: add checking read-only for the AuditMode and
    DeployedMode
  * securebootcert: move to UNSAFE category
- Changes for version 17.12.00:
  * ACPICA: Update to version 20171215
  * Fixed Bugs
  * acpi: tpm2: update spec url
  * trival: make read only const strings static
  * dmicheck: sbbr: make some SMBIOS structs optional
  * acpi: dbg2: sbbr: allow PL011 UART as a valid subtype
  * acpi: spcr: sbbr: IOAPIC is valid interrupt type
  * acpi: sbbr: relax a few test pass conditions
  * acpi: bert: remove confusing warning
  * acpi: madt: only inspect Local APIC/x2APIC/SAPIC tables if
    enabled
* Mon Dec 18 2017 mpluskal@suse.com
- Update to version 17.11.00:
  * acpi: devices: add a new test for acpi ec device
  * acpi: devices: add a new test for ACPI AC adapter device
  * acpi: devices: add a new test for ACPI battery device
  * acpi: devices: add a new test for smart battery device
  * acpi: devices: add new tests for power and sleep button devices
  * acpi: madt: check GICD's system vector according to mantis 1819
    (ACPI 6.2a)
  * acp: nfit: add platform capability according to manit 1831
    (ACPI 6.2a)
  * lib: add new large resource data type for _CRS methods
  * acpi: sdev: add ACPI SDEV test (mantis 1632)
  * acpi: dppt: add ACPI PDTT test (mantis 1576)
  * acpi: devices: add new tests for lid device
  * acpi: devices: add new tests for ambient light sensor device
  * acpi: devices: add new tests for time and alarm device
  * acpi: devices: add new tests for wireless power calibration
    device
  * acpi: add tests for _SRT control method
  * auto-packager: mkpackage.sh: add bionic
  * fwts: add bash command-line completion
  * Add ACPI 1.0 RSDP test to make sure RSDT field isn't null
  * ACPICA: Update to version 20171110
  * uefi: uefidump: add dumping for BluetoothLE device path
  * uefi: uefidump: add dumping for DNS device path
  * uefi: uefibootpath: add test for BluetoothLE device path
  * uefi: uefibootpath: add test for DNS device path
* Wed Nov 15 2017 mpluskal@suse.com
- Update to version 17.09.02:
  * No changelog provided
* Mon Oct  9 2017 mpluskal@suse.com
- Update to version 17.09.00:
  * ACPICA: Update to version 20170831
  * dmi: dmicheck: Add BMC Interface Type definitions from IPMI
    spec
  * lib: fwts_acpi_tables: add a new function to check Reserved
    field
  * lib: fwts_acpi_tables: add a new function to check reserved
    bits
  * efi_runtime: add resetsystem runtime service
- Refresh fwts-no-compiletime.patch
* Fri Sep 22 2017 mpluskal@suse.com
- Update to version 17.08.00:
  * ACPICA: Update to version 20170728
  * New ACPI tests defined by ACPI 6.2:
    + acpi: sdei: add ACPI SDEI test (mantis 1714)
    + acpi: pcct: refactor subspace to individual functions
    + acpi: pcct: update PCCT table to ACPI 6.2 (mantis 1659 &
    1755)
    + acpi: dppt: add ACPI DPPT test (mantis 1795)
    + acpi: pptt: add ACPI PPTT test
    + acpi: hmat: add ACPI HMAT test (mantis 1705)
    + acpi: method: add _LSI test according to ACPI 6.2 (mantis
    1721)
    + acpi: madt: Add support for ACPI 6.2
  * New tests for SBBR:
    + acpi: fadt: add SBBR compliance tests
    + acpi: madt: add SBBR compliance tests
    + acpi: spcr: add SBBR compliance tests
    + acpi: xsdt: add SBBR compliance tests
    + acpi: dbg2: add SBBR compliance tests
    + acpi: gtdt: add SBBR compliance tests
    + acpi: acpitables: add SBBR compliance tests
    + dmi: dmicheck: add SBBR compliance tests
    + acpi: method: add SBBR compliance tests
    + acpi: rsdp: add SBBR compliance tests
    + acpi: sbbr: sync up with new SBBR tests
  * dmicheck: fix dmi_reserved_bits_check function when size is 64
  * acpi: pmtt: fix typo from pmmt to pmtt
  * acpi: rasf: add ACPI RASF test
  * acpi: remove "Linux-ready Firmware Developer Kit" from license
    header of files not derived from the LFDK
  * opal: fix build error on Ubuntu 12.04 i386 with gcc 4.6.3
  * lib: fwts_safe_mem: remove need to copy into a buffer
  * acpi: bert: add safe memory read check on mmap'd memory
  * acpi: hpet: add safe memory read check on mmap'd memory
  * acpi: mcfg: add safe memory read check on mmap'd PCI config
    memory
  * acpi: pcc: add safe memory read check on mmap'd PCC header
  * bios: pciirq: add safe memory read check on mmap'd pci irq
    region
  * bios: pnp: add safe memory read check on mmap'd memory region
  * dmi: dmicheck: fix incorrect safe memory read check on DMI
    mmap'd region
  * uefi: csm: add safe memory read check on mmap'd interrupt and
    option ROM regions
  * fwts_safe_mem: workaround longjmp clobber warnings
  * lib: fwts_smbios: use fwts_safe_memcpy to read SMBIOS entry
  * lib: fwts_acpi_tables: re-work fwts_acpi_get_rsdp, less memory
    copies
  * lib: fwts_safe_mem: really force reads
  * lib: fwts_acpi_tables: unmap mem, fixes memory leak
  * acpi: xsdt: fix build error on 32 bit systems
  * acpica: fwts_acpica: fix linker issues on Fedora (LP: #1712572)
  * acpi: method: Fix error message.
- Refresh fwts-no-compiletime.patch
* Mon Aug 28 2017 mpluskal@suse.com
- Update to version 17.07.00 (boo#1055891):
  * acpi: bgrt: update according to acpi 6.1 errata
  * acpi: method: update _PSD and _TSD tests according to ACPI 6.1
    errata
  * acpi: rsdp: revision 1 must have length 20 according to ACPI
    6.1 errata
  * acpi: method: Add _CPC revision 3 according to ACPI 6.2
  * acpi: hest: add new type 11 introduced in ACPI 6.2
  * acpi: srat: add new type 4 according to ACPI 6.2
  * acpi: method: update _GCP according to ACPI 6.2
  * acpi: hest: add notification type 11 according to ACPI 6.2
  * acpi: fadt: update minor version to 2 for ACPI 6.2
  * acpi: hest: add checks for GHES_ASSIST flag value in ACPI 6.2
  * acpi: wsmt: add wsmt test according to ACPI 6.2
  * ACPICA: Update to version 20170629
  * acpi: tpm2: Add additional start method values
  * acpi: iort: Add PMCG support
* Thu Jun 22 2017 mpluskal@suse.com
- Update to version 17.06.00:
  * ACPICA: Update to version 20170531
  * olog: olog.json: Update OPAL skiboot errors to check on olog
    scan
  * bios: mtrr: print out actual default type of MTRR
  * lib: fwts_alloc: only parse mem info once we have a valid line
    read in
  * lib: fwts_safe_mem: add SIGBUS handling
  * lib: fwts_alloc: re-work the memory parsing again
  * acpi: method use correct format specifier for uint32_t type
  * bios: mtrr: fix compile error in ubuntu trusty
  * opal: fix tests dependency on libfdt
  * bios: mtrr: fix overlaped MTRR (LP: #1694710)
* Sun Jun  4 2017 mpluskal@suse.com
- Update to version 17.05.00:
  * Support SMBIOS 3.1.1 tests
  * dmi: dmicheck: check new offset in spec 3.11
  * dmi: dmicheck: check reserved bits of Type 7 offset 0x5
  * dmi: dmicheck: check reserved bits of Type 7 offset 0xd
  * dmi: dmicheck: add a function to verify reserved bits
  * dmi: dmicheck: add a helper function to check word min/max value
  * dmi: dmicheck: check pci(e) slot and segment, bus and dev/func
  * dmi: dmicheck: check reserved bits of offset 0x5 in type 13
  * dmi: dmicheck: add a helper function to check a reserved offset
  * dmi: dmicheck: check reserved bits in type 15 & type 17
  * dmi: dmicheck: check reserved fields in type 22, 23, 30, 32, 38 and 39
  * dmi: dmicheck: add 64-bit integer to dmi_reserved_bits_check
  * dmi: dmicheck: add checks for new type 43
  * dmi: dmicheck: check reserved bits in Type 0
  * fwts/opal: Power management DT Validation tests.
  * fwts/opal: Reserved memory DT validation tests.
  * Add snapcraft rules to build a fwts snap
* Fri Mar 24 2017 mpluskal@suse.com
- Update to version 17.03.00:
  * ACPICA: Update to version 20170224
  * sbbr: Add "--sbbr" flag to support running SBBR Tests.
  * acpi: iort: Add support for SMMUv3
  * lots of bugfixes
* Mon Feb 27 2017 mpluskal@suse.com
- Update to version 17.02.00:
  * ACPICA: Update to version 20170119
  * acpi: s3: Add new --s3-resume-hook option
  * Add README_JSON.txt for FWTS
  * klog.json: Add some more kernel messages to klog data base
  * klog.json: Add some EFI driver kernel messages to klog database
  * klog.json: Add some EFI quirk driver kernel messages to klog database
  * klog.json: Add some more EFI driver kernel messages to klog database
  * klog.json: Add some miscellaneous messages to klog database
  * Integrate PPC for FWTS-LIVE Frontend
  * fwts_framework: handle -? option differently from -h
- Rebase fwts-no-compiletime.patch
* Sat Jan 28 2017 mpluskal@suse.com
- Update to version 17.01.00:
  * ACPICA: Update to version 20161222
  * klog.json: Add kernel errors to the database
  * opal: pci_info: minor code style clean-ups
* Mon Jan  2 2017 mpluskal@suse.com
- Update to version 16.12.0 (boo#1017763):
  * ACPICA: Update to version 20161117
  * klog.json: Add a few more kernel errors to the database
  * opal: pci_info: Add OPAL PCI Info validation
  * opal: mem_info: Add OPAL MEM Info validation
  * opal: cpu_info: Add OPAL CPU Info validation
  * securebootcert: add variable AuditMode checking
  * securebootcert: add variable DeployedMode checking
  * lots of bugfixes
* Thu Dec  1 2016 mpluskal@suse.com
- Replace requires with recommends for dependencies
* Sun Nov 13 2016 mpluskal@suse.com
- Update to version 16.11.00:
  * ACPICA: Update to version 20160930
  * uefibootpath: add test for eMMC device path
  * uefidump: add dumping for the eMMC device path
  * miscelanous bugfixes
* Sun Sep 11 2016 mpluskal@suse.com
- Update to version 16.09.00:
  * lib: acpi: add supports for WPBT
  * acpi: wpbt: add ACPI WPBT test
  * lib: acpi: add supports for DRTM
  * acpi: drtm: add ACPI DRTM test
  * lib: fwts_guid: add a compare function
  * acpi: nfit: check fields equals 0 for Virtual CD and Disk
  * opal: mtd: Add OPAL MTD Validation
  * acpi: ACPI Platform check updates
  * acpi: fadt: Remove HEADLESS check on reduced hardware
  * pci: aspm: Add segment support
  * ACPICA: Update to version 20160831
  * lots of bugs fixed
- Drop no longer needed json-c-includes.patch
- Exclude s390x from building
* Thu Aug 18 2016 mpluskal@suse.com
- Update to version 16.08.00 (boo#994319):
  * acpi: nfit: add ACPI NFIT test
  * lib: acpi: add support for MPST
  * acpi: mpst: add ACPI MPST test
  * lib: acpi: add support for PMTT
  * acpi: pmtt: add ACPI PMTT test
  * ACPICA: Update to version 20160729
  * lots of bugfixes
* Sun Jul 31 2016 mpluskal@suse.com
- Update to version 16.07.00:
  * --uefi and --acpi options renamed to --uefitests and
  - -acpitests
  * ACPI table tests in the acpitables test have been moved into
    specific ACPI tests.
  * cpi: acpidump: update TCPA table and acpidump accordingly
  * acpi: add ACPI TCPA test
  * acpi: add XENV table test
  * lib: fwts_framework: Append "tests" to --uefi and --acpi
  * live-image/fwts-frontend-text: update to --uefitests and
  - -acpitests
  * lib: acpi, acpidump: rename slit tables types
  * lib: acpi: add in new GICC table fwts_acpi_table_gicc_affinity
  * acpi: add SRAT table sanity checking (LP: #1464658)
  * acpi: add BERT table sanity checking (LP: #1464712)
  * lib: acpi: Add in GAS address types
  * acpi: add ECDT table sanity checking (LP: #1464716)
  * lib: acpi: Add support for the SPMI table
  * acpi: add ACPI SPMI table sanity checking (LP: #1465256)
  * acpi: add ACPI SLIT table sanity checking (LP: #1465276)
  * lib: acpi: Add support for the HEST family of ACPI tables
  * acpi: add ACPI HEST table sanity checking (LP: #1465379)
  * acpi: Add BOOT table test (LP: #1465435)
  * acpi: Add DBGP table test (LP: #1465441)
  * acpi: Add DBG2 table test (LP: #1465710)
  * acpi: re-orgainise HPET tests
  * acpi: move MADT test from acpitables into new MADT test
  * acpi: move GTDT test from acpitables into new GTDT test
  * acpi: move XSDT test from acpitables into new XSDT test
  * acpi: move RSDP test from acpitables into new RSDP test
  * acpi: move RSDT test from acpitables into new RSDT test
  * acpi: acpitables: remove no-op MCFG test
  * acpi: move SBST test from acpitables into new SBST test
  * acpi: move FADT test from acpitables into existing FADT test
  * acpi: acpitables: remove redundant acpi table checking
  * acpi: allow various ACPI table tests to run without root access
  * lib: fwts_acpi_tables: fully pad out fixed up ACPI OEM IDs
  * acpi: spcr: add missing white space in error messages
  * acpi: add ACPI ERST test (LP: #1467835)
  * acpi: correct ACPI BGRT table type
  * acpi: add ACPI BGRT test (LP: #1467863)
  * acpi: add ACPI CPEP test (LP: #1467870)
  * acpi: add ACPI FACS test (LP: #1467966)
  * acpi: acpidump: add in missing exponent field to SLIC
  * acpi: add CSRT ACPI Table test (LP: #1470116)
  * acpi: add LPIT ACPI test (LP: #1470184)
  * acpi: add WAET ACPI table test (LP: #1470495)
  * acpi: add SLIC table test (LP: #1470518)
  * acpi: add MSDM table test (LP: #1470538)
  * acpi: add UEFI ACPI data table test (LP: #1471698)
  * bios: os2gap: remove ancient legacy test (LP: #1470573)
  * lost of bugfixes
* Sat Jul 16 2016 mpluskal@suse.com
- Update to version 16.06.01:
  * lib: acpi: add an acpi category
  * live-image/fwts-frontend-text: add selections of acpi and uefi
    tests
  * acpi: add tests to acpi category
  * acpi: fwts-tests: Remove redundant tailing space and update
    fwts-tests
  * auto-packager: mkpackage.sh: remove lucid
  * auto-packager: mkpackage.sh: add wily
  * acpi: Add SPCR ACPI table check (LP: #1433604)
  * dmi: dmicheck: add 4 new DMI chassis types
  * lots of bugfixes
- Enable building on all architectures
* Wed May 18 2016 mpluskal@suse.com
- Update to version 16.05.01:
  * ACPICA: Update to version 20160108 (LP: #1532268)
  * acpi: method: add _PTC test
  * sync with uefi 2.5 global variables
    + uefidump: add dumping global variabl AuditMode
    + uefidump: add dumping global variabl DeployedMode
    + uefidump: add dumping global variable OsRecoveryOrder
    + uefidump: add dumping global variable PlatformRecovery####
    + uefidump: add dumping global variable SysPrepOrder
    + uefidump: add dumping global variable SysPrep####
  * ACPICA: Update to version 20151218 (LP: #1527733)
  * esrtdump: add dumping for esrt table (LP: #1532103)
  * Fix spelling mistakes of "ACPI"
  * method: update method status
  * utilities: kernelscan: fix memory leaks and a segfault
  * acpi: cstates: fix clang build warning on zero CPUs.
  * acpi: s3, s3power, s4: replace cleanup free with explicit frees
  * data: klog.json: add in some more kernel error messages for 4.4
    (LP: #1526746)
  * acpi: hpet: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
  * acpi: pcc: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
  * bios: ebdadump: fwts_mmap failure is FWTS_MAP_FAILED and not
    MAP_FAILED
  * acpi: syntaxcheck: ASL_MSG_COMPILER_RESERVED failure should be
    an info (LP: #1529717)
  * Update copyright year to 2016
  * dmi: dmicheck: fix reserved bits mask for Processor Information
  * uefirtvariable: fix decalred VLA have zero size (LP: #1526815)
* Thu Mar 17 2016 mpluskal@suse.com
- Update to 16.03.00
  * acpi: method: add _PTC test
  * sync with uefi 2.5 global variables
    + uefidump: add dumping global variabl AuditMode
    + uefidump: add dumping global variabl DeployedMode
    + uefidump: add dumping global variable OsRecoveryOrder
    + uefidump: add dumping global variable PlatformRecovery####
    + uefidump: add dumping global variable SysPrepOrder
    + uefidump: add dumping global variable SysPrep####
    + ACPICA: Update to version 20151218 (LP: #1527733)
    + esrtdump: add dumping for esrt table (LP: #1532103)
  * Fix spelling mistakes of "ACPI"
  * method: update method status
  * utilities: kernelscan: fix memory leaks and a segfault
  * acpi: cstates: fix clang build warning on zero CPUs.
  * acpi: s3, s3power, s4: replace cleanup free with explicit frees
  * data: klog.json: add in some more kernel error messages for 4.4
    (LP: #1526746)
  * acpi: hpet: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
  * acpi: pcc: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
  * bios: ebdadump: fwts_mmap failure is FWTS_MAP_FAILED and not
    MAP_FAILED
  * acpi: syntaxcheck: ASL_MSG_COMPILER_RESERVED failure should be
    an info (LP:#1529717)
  * Update copyright year to 2016
  * dmi: dmicheck: fix reserved bits mask for Processor
    Information
  * uefirtvariable: fix decalred VLA have zero size (LP: #1526815)
* Thu Feb 25 2016 mpluskal@suse.com
- Update to 16.02.00
  * Start defining FWTS architectures as variables
  * Define some utility functions for using the fwts_architecture
    enum
  * Add mechanism to tell FWTS what architecture is being tested
  * ACPI: MADT: add in compliance tests for the MADT and subtables
  * ACPI: Add in MADT subtable description for GIC ITS subtable
  * ACPI: MADT: add in compliance checks for the GIC ITS subtable
  * Documentation: add --acpicompliance to man page
  * Documentation: add --arch to the man page
  * RSDP: minor cleanups to rsdp.c for checkpatch issues
  * utilities: add a helper function for printing out architecture
    names
  * ACPI tables: when bodging up an RSDP, do the right thing for
    the arch
  * ACPI RSDP: flesh out the tests to check for full spec
    compliance.
  * Update regression test rsdp-0001/test-0001.sh
  * Update the regression test arg-help-0001/test-0001.sh
  * Update regression test for arg-help-0001/test-0002.sh
  * Update regression test for arg-show-tests-0001/test-0001.sh
  * Update regression test arg-show-tests-full-0001/test-0001.sh
  * Update the regression test arg-table-path-0001/test-0001.sh
  * Update the regression test madt-0001/test-0001.sh
  * Update the regression test madt-0001/test-0002.sh
  * FADT: enable compiling on non-x86 architectures
  * FADT: non-x86 machines need an FADT but x86 can survive
    without one
  * FADT: disable SCI_EN and RESET_REG tests when in reduced
    hardware mode
  * FADT: add in code to log basic info about the various FADT
    flag fields
  * Add in bit masks for FACS flags.
  * FADT: move log info out of test2, will provide it elsewhere
  * ACPI: Add hypervisor ID field to FADT.
  * FADT: minor cleanup and initial compliance tests
  * FADT: expand the compliance test for FIRMWARE_CTRL fields
  * FADT: expand compliance checks for DSDT and X_DSDT fields
  * FADT: add compliance tests for reserved fields, PM profile,
    reduced hardware
  * FADT: restructure test sequence around reduced hardware mode
  * FADT: expand compliance tests for the SMI_CMD field
  * FADT: add compliance tests for the ACPI_ENABLE and
    ACPI_DISABLE fields
  * FADT: add compliance tests for S4BIOS_REQ and PSTATE_CNT
    fields
  * FADT: extend and add PM address block compliance tests
  * FADT: enhance compliance tests for GPE blocks
  * FADT: add compliance test for the CST_CNT field
  * FADT: add in compliance tests for C2/C3 latency fields
  * FADT: add in SLEEP_CONTROL_REG and SLEEP_STATUS_REG
    compliance tests
  * FADT: remove no longer useful variables from test1
  * FADT: add safety checks for older versions of FADT
  * FADT: update regression tests to incorporate new/changed
    tests
  * acpi: method: add _PMC test
  * acpi: method: add _PRT test
  * fwts-test: update for _PMC and _PRT tests
  * acpi: method: add _RDI test
  * acpi: method: add _LPI test
  * fwts-test: update for _RDI and _LPI tests
  * acpi: method: remove non-method names from the top comments
  * acpi: erst: fix incorrect error message for reserved field
  * fwts-test: update erst test for the fix of reserved field
  * lib: fwts_klog: fix incorrect indentation, detected by gcc-6
  * lib: fwts_hwinfo: clean up type punning, fixes warning with
    gcc-6
  * fwts: wakealarm: reset wakealarm timer at end of test
    (LP: #1534003)
  * Update arg-show-tests-full now that we have an extra test in
    wakealarm
  * dmi: dmicheck: add some simple sanity checks to table size
  * lib: fwts_args: use safer strncat than strcat
  * lib: fwts_acpi_tables: don't do expensive low allocs multiple
    times
  * acpi: fadt: check 32/64 bit PM register addresses for
    inconsistency (LP: #1536606)
  * acpi: madt: fix incorrect format specifier for size_t
  * cpu: microcode: fix a couple of warnings found by cppcheck:
  * acpi: madt: clean up some minor style issues detected by
    cppcheck
  * data: klog.json: update to sync with 4.6 kernel changes
  * ACPICA: Update to version 20160212 (LP: #1545099)
  * lib: fwts_acpi_tables: fix warnings found by clang scan-build
  * lib: fwts_cpu: check for MSR read failures
  * lib: fwts_klog: handle the case where klog_old is empty list
  * acpica: fix disassembly on i386 platforms (LP: #1547469)
  * lib: fwts_arch: i686 arch name is also an X86 arch
    (LP: #1547554)
  * fwts-test: only run rsdp regression test on specific arches
    (LP: #1547602)
  * Fix null_gass initializer for older versions of gcc
    (LP: #1549429)
  * fwts-test: sync up with the arg-table-path
* Sun Jan 17 2016 mpluskal@suse.com
- Update to 16.01.00
  * ACPICA: Update to version 20160108
  * acpi: method: add _PTC test
  * sync with uefi 2.5 global variables
    + uefidump: add dumping global variabl AuditMode
    + uefidump: add dumping global variabl DeployedMode
    + uefidump: add dumping global variable OsRecoveryOrder
    + uefidump: add dumping global variable PlatformRecovery####
    + uefidump: add dumping global variable SysPrepOrder
    + uefidump: add dumping global variable SysPrep####
  * ACPICA: Update to version 20151218
  * esrtdump: add dumping for esrt table
  * fixed bugs:
    + Fix spelling mistakes of "ACPI"
    + method: update method status
    + utilities: kernelscan: fix memory leaks and a segfault
    + acpi: cstates: fix clang build warning on zero CPUs.
    + acpi: s3, s3power, s4: replace cleanup free with explicit
    frees
    + data: klog.json: add in some more kernel error messages for
    4.4
    + acpi: hpet: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
    + acpi: pcc: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
    + bios: ebdadump: fwts_mmap failure is FWTS_MAP_FAILED and not
    MAP_FAILED
    + acpi: syntaxcheck: ASL_MSG_COMPILER_RESERVED failure should
    be an info
    + Update copyright year to 2016
    + dmi: dmicheck: fix reserved bits mask for Processor
    Information
    + uefirtvariable: fix decalred VLA have zero size
* Sat Dec 19 2015 mpluskal@suse.com
- Update to 05.12.00
  * Update ACPICA to version 20151124
  * live-image/fwts-frontend-text: add a selection for recommended
  * data: klog.json: add in some more kernel error messages for
  4.3
  * ACPI: Add ASPT test
  * lib: framework: allow mixed tests and test category options
  * fwts: framework: Add --log-level option
  * lib: fwts_uefi: add SD device path define
  * Boot path sync with UEFI spec. 2.5
  + uefibootpath: add test for the SD device path
  + uefidump: add dumping for the SD device path
  + lib: fwts_uefi: add efi bluetooth device path define
  + uefibootpath: add test for the bluetooth device path
  + uefidump: add dumping for the bluetooth device path
  + lib: fwts_uefi: add wireless device path define
  + uefibootpath: add test for the wireless device path
  + uefidump: add dumping for the wireless device path
  + lib: fwts_uefi: add ramdisk device path define
  + uefibootpath: add test for the ramdisk device path
  + uefidump: add dumping for the ramdisk device path
  * Fixed bugs
  + acpi: fpdt: add a terminate for buggy BIOS that reports zero
  length
  + lib: klog: remove use of pcre, use regex instead
  + utilities: kernelscan: remove use of pcre, use regex instead
  + uefidump: add more bounds checking and remove need for heap
  + utilities: fix memory leak, line not being free'd
  + acpi: bert: remove redundant variable 'length'
  + lib: iasl: rework IASL interface to ACPICA
  + acpi: acpidump: use IASL rather than fwts custom table dump
  code
  + s3 + klog: make log scanning more robust for S3 (LP: #1522292)
  + lib: acpica: make region handler more robust (LP: #1524217)
  + debian: copyright, fix lintian warnings
  + Debian: update Standards-Version to 3.9.6
  + acpi: acpidump: check for fwts_iasl_init failure
  + lib: fwts_acpi_tables: fix segfault when tables fail to load
  (LP: #1452201)
  + acpi: dbg2: remove dead store to ptr1
  + hotkey: fix key reading loop, it needs to loop more than once
  + lib: fwts_framework: remove dead store to len in for loop
  + lib: fwts_acpi_table: remove redundant store to rsdt
  + acpi: gpedump: remove redundant store to gpe_xrupt_info
  + lib: fwts_acpi_tables: remove dead store to facs
  + acpica: fwts_acpica: remove redundant store to length
  + lib: fwts_acpi_tables: remove redundant store to xsdt
  + lib: fwts_acpi_tables: check table to avoid dereferencing
  NULL ptr
  + lib: fwts_acpi_table: Fix FADT update in creation of fake
  FACS table.
  + uefibootpath: fix the wrong type for relative offset range
  path
* Tue Nov 17 2015 mpluskal@suse.com
- Update to 05.11.00
  * Update ACPICA to version 20150930
  * New Features
  + Add in the notion of ACPI compliance tests.
  + MADT subtables: Local SAPIC structure has 3 reserved bytes,
  not 1
  + ACPI: MADT: update GICC flag checks for ACPI 6.0
  + ACPI: MADT: further update to GICC flag checks for 6.0
  + acpi: method: skip scope names in method_evaluate_method
  + acpi: method: add _GPE test
  + acpi: method: add _TSN test
  + acpi: method: add _TFP test
  + acpi: method: add _EC test
  + acpi: method: add _CWS test
  + acpi: method: add _BTH test
  + auto-packager: mkpackage.sh: add xenial
  + acpi: tpm2: add check for zero control area address (LP:
  [#1506442])
  + securebootcert: change fail to warning when MS UEFI CA not
  found in DB
  + lib: fwts_uefi: add BMC device path define
  + uefidump: add dumping the BMC device path
  + uefibootpath: add test for the BMC device path
  + lib: fwts_uefi: add the URI device path define
  + uefibootpath: add test for the URI device path
  + uefidump: add dumping for the URI device path
  + lib: fwts_uefi: add the UFS device path define
  + uefidump: add dumping for the UFS device path
  + uefibootpath: add test for the UFS device path
  * Fixed Bugs
  + dmi: dmicheck: fix SMBIOS issues on aarch64 systems
  + acpidump: add missing reserved fields to MADT structures
  + cpufreq: the calibration is taking a long time, make it
  faster
  + acpi: tcpa: replace tab with spaces to fix formatting
  alignment
* Wed Sep 23 2015 mpluskal@suse.com
- Update to 05.09.00
  * Update ACPICA to version 20150717
  * SMBios 3.0.0 tests supported
  * new features:
  + acpi: method: add _CR3 test
  + acpi: method: add _MTL test
  + acpi: method: add _RST test
  + acpi: method: add _PRR test
  + data: klog.json: sync with latest 4.2 kernel messages
    (LP: #1493039)
  + lib: smbios: add smbios version 3.0.0 entry find helper
  + dmicheck: add test for smbios 3.0.0 entry point
  + dmicheck: add error test for SMBIOS 3.0.0 table
  + dmicheck: sync the dmi value test with smbios 3.0.0 spec
  * fixed bugs:
  + acpi: fadt: merge tests for reset register
  + cpu: cpufreq: reduce scope of variables
  + acpi: gpedump: clarify precedence for & and ?
  + lib: fwts_cpu: reduce scope on variables
  + ACPICA: Update to version 20150717 (LP: #1486253)
  + lib: fwts_log: re-work to clean up va_arg scoping
  + uefi: uefirtvariable: clean up cppcheck style warning
  + acpi: rsdp: make OEM ID test less strict
  + fix some spelling mistakes in code and sync fwts-tests
    accordingly
  + cpu: maxfreq: check for unlikely event that no CPUs in cpu
    list
  + acpi: crsdump: fix incorrect use of string size in string
    copies
  + lib: fwts_acpi_tables: add checking for empty table parsing
  + lib: fwts_acpi_table: remove dead initialisation of ptr
  + dmi: dmicheck: fix build error on 32 bit builds
  + Makefile.am: use pkg-config for json-c
  + lib: fwts_smbios: fix the smbios version from uefi always
    zero (LP: #1484023)
  + lib: fwts_scan_efi_systable: fix getting wrong smbios entry
    (LP: #1484046)
  + acpi: dbg2: won't find obj when no namespace device path
    (lp: #1486893)
  + lib: fwts_smbios: add the struct definition for smbios
    3.0.0
  + dmicheck: re-orgainise the smbios entry point check
  + dmicheck: fix the Base Board type range typos
  + auto-packager: mkpackage.sh: remove utopic
* Mon Aug 24 2015 dvaleev@suse.com
- Set exclusive arch to intel architectures (BIOS)
* Thu Aug 20 2015 mpluskal@suse.com
- Update to 15.08.00
  * new features:
    + acpi: tpm2: Add ACPI TPM2 test
    + acpi: method: add support for _CPC revision 2
    + acpi: add support for FPDT table (LP: #1476954)
    + acpi: add ACPI IORT test (LP: #1450440)
    + ACPICA: Update to version 20150717 (LP: #1475733)
    + acpi: Add support for MCHI Table (LP: #1478951)
    + acpi: Add support for STAO Table (LP: #1478957)
    + acpi: Add support for ASF! Table (LP: #1479736)
    + acpi: Add support for WDAT Table (LP: #1480257)
  * fixed bugs
    + acpi: add table names in test description
    + acpi: remove redundant tailing spaces - no functional
    changes
    + acpi: tcpa: fix incorrect comments - no functional changes
    + acpi: method: fix incorrect shift of 64-bit integer in CRS
    + acpi: acpidump: change FADT flag BIT20 to Hardware-reduce
    ACPI
    + acpi: update MADT GIC Distributor Structure and related
    tests
    + acpi: update MADT GICC Structure and related tests
    + acpi: fadt: update fadt_dsdt test with x_dsdt field
    + acpi: fadt: check RESET_REG_SUP before checking the reset
    register
    + acpi: method: refine _AEI control method
    + acpi: method: refine _EVT test
    + fwts: Better options handling for --dump
    + lib: Allow reading ACPI dump file by non-root user
    + acpi: XENV: fix a few spelling mistakes and fix up
    copyright
    + acpi: LPIT: remove duplicate "LPIT" from test description
    + acpi: HPET: fix typo in HPET description field
    + acpi: iort: fix build warning on older versions of GCC
    + lib: fwts_framework: remove dubious total of
  - -show-tests-full
    + acpidump: update mchi to latest revision of MCHI
    specification
    + lib: fix build error on non-Intel platforms
    + acpi: correct ASF! table definitions
    + lib: acpi.h: clean up comments and code - add more
    references
    + cpu/cpufreq: Iterate over the correct number of CPUs
    in test_sw_any
* Tue Jul 14 2015 mpluskal@suse.com
- Update to 15.07.00
  * --uefi and --acpi options renamed to --uefitests and
  - -acpitests
  * ACPI table tests in the acpitables test have been moved into
    specific ACPI tests.
  * acpi: acpidump: update TCPA table and acpidump accordingly
  * acpi: add ACPI TCPA test
  * acpi: add XENV table test
  * lib: fwts_framework: Append "tests" to --uefi and --acpi
  * live-image/fwts-frontend-text: update to --uefitests and
  - -acpitests
  * lib: acpi, acpidump: rename slit tables types
  * lib: acpi: add in new GICC table fwts_acpi_table_gicc_affinity
  * acpi: add SRAT table sanity checking (LP: #1464658)
  * acpi: add BERT table sanity checking (LP: #1464712)
  * lib: acpi: Add in GAS address types
  * acpi: add ECDT table sanity checking (LP: #1464716)
  * lib: acpi: Add support for the SPMI table
  * acpi: add ACPI SPMI table sanity checking (LP: #1465256)
  * acpi: add ACPI SLIT table sanity checking (LP: #1465276)
  * lib: acpi: Add support for the HEST family of ACPI tables
  * acpi: add ACPI HEST table sanity checking (LP: #1465379)
  * acpi: Add BOOT table test (LP: #1465435)
  * acpi: Add DBGP table test (LP: #1465441)
  * acpi: Add DBG2 table test (LP: #1465710)
  * acpi: re-orgainise HPET tests
  * acpi: move MADT test from acpitables into new MADT test
  * acpi: move GTDT test from acpitables into new GTDT test
  * acpi: move XSDT test from acpitables into new XSDT test
  * acpi: move RSDP test from acpitables into new RSDP test
  * acpi: move RSDT test from acpitables into new RSDT test
  * acpi: acpitables: remove no-op MCFG test
  * acpi: move SBST test from acpitables into new SBST test
  * acpi: move FADT test from acpitables into existing FADT test
  * acpi: acpitables: remove redundant acpi table checking
  * acpi: allow various ACPI table tests to run without root access
  * lib: fwts_acpi_tables: fully pad out fixed up ACPI OEM IDs
  * acpi: spcr: add missing white space in error messages
  * acpi: add ACPI ERST test (LP: #1467835)
  * acpi: correct ACPI BGRT table type
  * acpi: add ACPI BGRT test (LP: #1467863)
  * acpi: add ACPI CPEP test (LP: #1467870)
  * acpi: add ACPI FACS test (LP: #1467966)
  * acpi: acpidump: add in missing exponent field to SLIC
  * acpi: add CSRT ACPI Table test (LP: #1470116)
  * acpi: add LPIT ACPI test (LP: #1470184)
  * acpi: add WAET ACPI table test (LP: #1470495)
  * acpi: add SLIC table test (LP: #1470518)
  * acpi: add MSDM table test (LP: #1470538)
  * acpi: add UEFI ACPI data table test (LP: #1471698)
  * bios: os2gap: remove ancient legacy test (LP: #1470573)
- add fwts-no-compiletime.patch (based on patch from acpica)
* Tue Jun 16 2015 mpluskal@suse.com
- Update to 15.06.00
  * lib: acpi: add an acpi category
  * live-image/fwts-frontend-text: add selections of acpi and uefi
    tests
  * acpi: add tests to acpi category
  * acpi: fwts-tests: Remove redundant tailing space and update
    fwts-tests
  * auto-packager: mkpackage.sh: remove lucid
  * auto-packager: mkpackage.sh: add wily
  * acpi: Add SPCR ACPI table check (LP: #1433604)
  * dmi: dmicheck: add 4 new DMI chassis types
  * uefi: uefirtvariable: Add invalid NULL parameter sanity checks
  * lib: fwts_acpi_tables: print correct pathname on error
  * lib: fwts_acpi_tables: set count correctly on error
  * lib: fwts_acpi_tables: only attempt to open a dumpfile if name
    is defined
  * pci: aspm: check that a table exists, fixes segv on arm64
  * lib: fwts_smbios: only scan memory for DMI table if x86
  * acpi: spcr: remove unnecessary include files and fix ARM build
    issue
  * pci: maxreadreq: skip test if /sys/bus/pci/devices is not
    available
  * acpi: spcr: issue a passed message if SPCR test passes
  * lib: fwts_alloc: provide fallback low memory allocator strategy
    (LP: #1452168)
  * bios: mtrr: fix memory leak on mtrr entries
  * hotkey: only process reads of hotkey events that are at least
    the correct length
  * uefi: uefirtvariable: fix incorrect buffer size being passed
  * lib: fwts_acpi_tables: enforce stricter table loading checks
  * lib: acpica: explicitly set buffer to NULL to remove cppcheck
    warning
  * acpica: fwts_iasl_interface: clean up static analyzer warning
    on freopen
  * lib: fwts_pipe: clean up static analyzer warning on freopen
  * uefi: efi_runtime: eliminate confusing error message of
    get_variable
  * acpi: method: _PRS is not mandatory method
  * acpi: acpitables: FADT: Ignore fields at offset 46 through 108
    for HW_REDUCED_ACPI
  * efi_runtime: get_nextvariablename: Fix bug of name string copy
  * fwts: Add fwts_firmware_has_features
  * fwts: Only run firmware detection once
  * fwts: Allow tests to be conditional on available features
  * fwts: Print names of missing features, rather than a cryptic
    bitmask
  * fwts: Add FWTS_FW_FEATURE_DEVICETREE
  * fwts: Add OPAL firmware type
  * cpu/cpufreq: Don't reparse cpu information
  * cpu/cpufreq: hz_almost_equal is unused if !FWTS_ARCH_INTEL
  * cpu/cpufreq: Add a separate cpufreq consistency test
  * cpu/cpufreq: Add test for duplicate entries in cpufreq tables
  * cpu/cpufreq: Do bios limit and claimed max checks as separate
    tests
  * cpu/cpufreq: Refactor CPU performance tests
  * cpu/cpufreq: Always check that cpufreq changes have taken
  * fwts: Use linux perf counters for cpu benchmarking
  * fwts: Use gettimeofday for cpu benchmark
  * fwts: scale cpu benchmark results to one second
  * cpu/cpufreq: Only run performance tests on master threads
* Sat May  9 2015 jengelh@inai.de
- Drop unnecessary ldconfig call: there are no libraries shipped
  in the standard search paths.
- Pacify rpmlint warning about devel-file-in-non-devel-package
* Wed Apr 22 2015 mpluskal@suse.com
- Update to 15.03.01
  * uefi: uefirttime: Add tests to exercise invalid parameters
  * acpi: acpitables: add GTDT checking
  * lib: fwts_acpi_tables: load tables from /sys (LP: #1437043)
  * efi_runtime: ensure we don't allocate a zero byte buffer
    (LP: #1429890)]
  * acpi: acpitables: make length and skip signed to handle -ve
    underflow (LP: #1435272)
  * uefi: uefidump: don't dump non-printable variable contents
    (LP: #1435346)
  * uefi: uefirtmisc: Add null count argument check for
    GetNextHighMonotonicCount
  * uefirtauthvar: return error when get mismatch size
  * uefirtauthvar: dependency checking for existence of test data (
    (LP: #1434408)
  * uefirtauthvar: remove duplicate authenticated attribute test
    (LP: #1432752)
* Sun Mar 29 2015 mpluskal@suse.com
- Update to 15.03.00
- Remove patches fwts-linking.patch and fwts-opensuse.patch
- Add json-c-includes.patch
* Wed Feb  1 2012 crrodriguez@opensuse.org
- Fix linking
* Mon Dec 12 2011 crrodriguez@opensuse.org
- Update to version fwts-0.24.13
* Wed Sep  1 2010 stepan@coresystems.de
- initial package of fwts (version 0.18.1)
